@@ -200,6 +200,31 @@ from rapida.utils.rapida_header import (
 #     CreateProjectCredential,
 # )
 from rapida.clients.call import create_phone_call, create_bulk_phone_call
+from rapida.clients.assistant import (
+    get_assistant,
+    get_all_assistant,
+    get_assistant_conversation,
+    get_all_assistant_conversation,
+    get_assistant_webhook,
+    get_all_assistant_webhook,
+    get_assistant_knowledge,
+    get_all_assistant_knowledge,
+    get_assistant_tool,
+    get_all_assistant_tool,
+    get_assistant_webhook_log,
+    get_all_assistant_webhook_log,
+    get_assistant_analysis,
+    get_all_assistant_analysis,
+)
+
+from rapida.clients.endpoint import (
+    get_endpoint,
+    get_all_endpoint,
+    get_endpoint_log,
+    get_all_endpoint_log,
+)
+
+from rapida.clients.invoke import invoke
 
 # # Protobuf imports
 from rapida.clients.protos.assistant_knowledge_pb2 import (
@@ -464,22 +489,11 @@ from rapida.clients.protos.integration_api_pb2 import (
 )
 from rapida.clients.protos.assistant_deployment_pb2 import (
     DeploymentAudioProvider,
-    AssistantDeploymentCapturer,
     AssistantWebpluginDeployment,
     AssistantPhoneDeployment,
     AssistantWhatsappDeployment,
     AssistantDebuggerDeployment,
     AssistantApiDeployment,
-    CreateAssistantApiDeploymentRequest,
-    AssistantApiDeploymentResponse,
-    CreateAssistantPhoneDeploymentRequest,
-    AssistantPhoneDeploymentResponse,
-    CreateAssistantWhatsappDeploymentRequest,
-    AssistantWhatsappDeploymentResponse,
-    CreateAssistantDebuggerDeploymentRequest,
-    AssistantDebuggerDeploymentResponse,
-    CreateAssistantWebpluginDeploymentRequest,
-    AssistantWebpluginDeploymentResponse,
     GetAssistantDeploymentRequest,
 )
 from rapida.clients.protos.knowledge_api_pb2 import (
@@ -522,8 +536,6 @@ from rapida.clients.protos.assistant_api_pb2 import (
     GetAllMessageResponse,
     UpdateAssistantVersionRequest,
     UpdateAssistantDetailRequest,
-    GetAllAssistantUserConversationRequest,
-    GetAllAssistantUserConversationResponse,
     GetAssistantConversationRequest,
     GetAssistantConversationResponse,
 )
@@ -569,6 +581,26 @@ __all__ = [
     "HEADER_REMOTE_URL",
     "HEADER_LATITUDE",
     "HEADER_LONGITUDE",
+    #
+    "get_assistant",
+    "get_all_assistant",
+    "get_assistant_conversation",
+    "get_all_assistant_conversation",
+    "get_assistant_webhook",
+    "get_all_assistant_webhook",
+    "get_assistant_knowledge",
+    "get_all_assistant_knowledge",
+    "get_assistant_tool",
+    "get_all_assistant_tool",
+    "get_assistant_webhook_log",
+    "get_all_assistant_webhook_log",
+    "get_endpoint",
+    "get_all_endpoint",
+    "get_endpoint_log",
+    "get_all_endpoint_log",
+    "invoke",
+    "get_assistant_analysis",
+    "get_all_assistant_analysis",
     #     "IndexKnowledgeDocument",
     #     "GetAllDeployment",
     #     "Invoke",
@@ -915,22 +947,11 @@ __all__ = [
     "GetModerationRequest",
     "GetModerationResponse",
     "DeploymentAudioProvider",
-    "AssistantDeploymentCapturer",
     "AssistantWebpluginDeployment",
     "AssistantPhoneDeployment",
     "AssistantWhatsappDeployment",
     "AssistantDebuggerDeployment",
     "AssistantApiDeployment",
-    "CreateAssistantApiDeploymentRequest",
-    "AssistantApiDeploymentResponse",
-    "CreateAssistantPhoneDeploymentRequest",
-    "AssistantPhoneDeploymentResponse",
-    "CreateAssistantWhatsappDeploymentRequest",
-    "AssistantWhatsappDeploymentResponse",
-    "CreateAssistantDebuggerDeploymentRequest",
-    "AssistantDebuggerDeploymentResponse",
-    "CreateAssistantWebpluginDeploymentRequest",
-    "AssistantWebpluginDeploymentResponse",
     "GetAssistantDeploymentRequest",
     "CreateKnowledgeRequest",
     "CreateKnowledgeResponse",
@@ -969,8 +990,6 @@ __all__ = [
     "GetAllMessageResponse",
     "UpdateAssistantVersionRequest",
     "UpdateAssistantDetailRequest",
-    "GetAllAssistantUserConversationRequest",
-    "GetAllAssistantUserConversationResponse",
     "GetAssistantConversationRequest",
     "GetAssistantConversationResponse",
 ]
